@@ -37,7 +37,7 @@ output <- eyeris::glassbox(demo_data)
 plot(
   output,
   steps = c(1, 5),
-  preview_window = c(0, nrow(output$timeseries$block_1)),
+  preview_window = c(0, max(output$timeseries$block_1$time_secs)),
   seed = 0
 )
 
